import React from 'react';
import { Icon, Button, Input, Select, Spin, Table, Switch, message, DatePicker, Modal } from 'antd';
import ajax from 'jquery/src/ajax/xhr.js';
import $ from 'jquery/src/ajax';
import moment from 'moment';
import './techDemand.less';
import TechDemandDesc from './techDemandDesc.jsx';
import { demandTypeList } from '../../dataDic.js';
import { companySearch, getDemandType } from '../../tools.js';

const DemandList = React.createClass({
    loadData(pageNo) {
        this.state.data = [];
        this.setState({
            loading: true
        });
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/user/demand/list",
            data: {
                pageNo: pageNo || 1,
                pageSize: this.state.pagination.pageSize,
                serialNumber: this.state.serialNumber,
                name: this.state.name,
                keyword: this.state.keyword,
                demandType: this.state.demandType ? Number(this.state.demandType) : undefined,
                status: this.state.status ? Number(this.state.status) : undefined,
                releaseStatus: this.state.releaseStatus ? Number(this.state.releaseStatus) : undefined,
                validityPeriodStartDate: this.state.validityPeriodDate[0],
                validityPeriodEndDate: this.state.validityPeriodDate[1],
                releaseDateStartDate: this.state.releaseDate[0],
                releaseDateEndDate: this.state.releaseDate[1],
                auditStatus: this.state.auditStatus
            },
            success: function (data) {
                let theArr = [];
                if (!data.data || !data.data.list) {
                    if (data.error && data.error.length) {
                        message.warning(data.error[0].message);
                    };
                } else {
                    for (let i = 0; i < data.data.list.length; i++) {
                        let thisdata = data.data.list[i];
                        theArr.push({
                            key: i,
                            id: thisdata.id,
                            serialNumber: thisdata.serialNumber,
                            dataCategory: thisdata.dataCategory,
                            name: thisdata.name,
                            keyword: thisdata.keyword,
                            releaseDate: thisdata.releaseDate,
                            demandType: thisdata.demandType,
                            validityPeriod: thisdata.validityPeriod,
                            status: thisdata.status,
                            releaseStatus: thisdata.releaseStatus,
                            employerId: thisdata.employerId,
                            releaseDateFormattedDate: thisdata.releaseDateFormattedDate,
                            validityPeriodFormattedDate: thisdata.validityPeriodFormattedDate,
                            auditStatus: thisdata.auditStatus
                        });
                    };
                }
                this.state.pagination.current = data.data.pageNo;
                this.state.pagination.total = data.data.totalCount;
                this.setState({
                    dataSource: theArr,
                    pagination: this.state.pagination
                });
            }.bind(this),
        }).always(function () {
            this.setState({
                loading: false
            });
        }.bind(this));
    },
    getInitialState() {
        return {
            searchMore: true,
            validityPeriodDate: [],
            releaseDate: [],
            selectedRowKeys: [],
            selectedRows: [],
            loading: false,
            pagination: {
                defaultCurrent: 1,
                defaultPageSize: 10,
                showQuickJumper: true,
                pageSize: 10,
                onChange: function (page) {
                    this.loadData(page);
                }.bind(this),
                showTotal: function (total) {
                    return '共' + total + '条数据';
                }
            },
            columns: [
                {
                    title: '编号',
                    dataIndex: 'serialNumber',
                    key: 'serialNumber',
                }, {
                    title: '需求名称',
                    dataIndex: 'name',
                    key: 'name',
                }, {
                    title: '关键字',
                    dataIndex: 'keyword',
                    key: 'keyword',
                }, {
                    title: '需求类型',
                    dataIndex: 'demandType',
                    key: 'demandType',
                    render: text => { return getDemandType(text); }
                }, {
                    title: '审核状态',
                    dataIndex: 'auditStatus',
                    key: 'auditStatus',
                    render: text => {
                        switch (text) {
                            case "0":
                                return <span>未提交审核(草稿)</span>;
                            case "1":
                                return <span>提交审核</span>;
                            case "2":
                                return <span>审核中</span>;
                            case "3":
                                return <span>审核通过</span>;
                            case "4":
                                return <span>审核未通过</span>;
                        }
                    }
                }, {
                    title: '需求状态',
                    dataIndex: 'status',
                    key: 'status',
                    render: text => {
                        switch (text) {
                            case "0":
                                return <span>进行中</span>;
                            case "1":
                                return <span>未解决</span>;
                            case "2":
                                return <span>已解决</span>;
                        }
                    }
                }, {
                    title: '有效期限',
                    dataIndex: 'validityPeriodFormattedDate',
                    key: 'validityPeriodFormattedDate',
                }, {
                    title: '发布时间',
                    dataIndex: 'releaseDateFormattedDate',
                    key: 'releaseDateFormattedDate',
                }
            ],
            dataSource: [],
            searchTime: [,]
        };
    },
    componentWillMount() {
        let theArr = [];
        demandTypeList.map(function (item) {
            theArr.push(
                <Select.Option value={item.value} key={item.key}>{item.key}</Select.Option>
            )
        });
        this.state.demandTypeOption = theArr;
        this.loadData();
    },
    tableRowClick(record, index) {
        this.state.RowData = record;
        this.setState({
            showDesc: true
        });
    },
    delectRow() {
        let deletedIds = [];
        for (let idx = 0; idx < this.state.selectedRows.length; idx++) {
            let rowItem = this.state.selectedRows[idx];
            if (rowItem.id) {
                deletedIds.push(rowItem.id)
            };
        };
        this.setState({
            selectedRowKeys: [],
            loading: deletedIds.length > 0
        });
        $.ajax({
            method: "POST",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/user/demand/delete",
            data: {
                ids: deletedIds
            }
        }).done(function (data) {
            if (!data.error.length) {
                message.success('删除成功！');
                this.setState({
                    loading: false,
                });
            } else {
                message.warning(data.error[0].message);
            };
            this.loadData();
        }.bind(this));
    },
    addClick() {
        this.state.RowData = {};
        this.setState({
            showDesc: true
        });
    },
    closeDesc(e, s) {
        this.state.showDesc = e;
        if (s) {
            this.loadData();
        };
    },
    search() {
        this.loadData();
    },
    reset() {
        this.state.serialNumber = undefined;
        this.state.auditStatus = undefined;
        this.state.name = undefined;
        this.state.keyword = undefined;
        this.state.demandType = undefined;
        this.state.username = undefined;
        this.state.status = undefined;
        this.state.releaseStatus = undefined;
        this.state.validityPeriodDate = [];
        this.state.releaseDate = [];
        this.loadData();
    },
    searchSwitch() {
        this.setState({
            searchMore: !this.state.searchMore
        });
    },
    render() {
        const rowSelection = {
            selectedRowKeys: this.state.selectedRowKeys,
            onChange: (selectedRowKeys, selectedRows) => {
                this.setState({
                    selectedRows: selectedRows.slice(-1),
                    selectedRowKeys: selectedRowKeys.slice(-1)
                });
            }
        };
        const hasSelected = this.state.selectedRowKeys.length > 0;
        const { RangePicker } = DatePicker;
        return (
            <div className="user-content" >
                <div className="content-title">
                    <span>科技需求管理</span>
                    <div className="patent-addNew">
                        <Button type="primary" onClick={this.addClick}>新增需求<Icon type="plus" /></Button>
                    </div>
                </div>
                <div className="user-search">
                    <Input placeholder="需求编号"
                        value={this.state.serialNumber}
                        onChange={(e) => { this.setState({ serialNumber: e.target.value }); }} />
                    <Input placeholder="需求名称"
                        value={this.state.name}
                        onChange={(e) => { this.setState({ name: e.target.value }); }} />
                    <Input placeholder="关键字"
                        value={this.state.keyword}
                        onChange={(e) => { this.setState({ keyword: e.target.value }); }} />
                    <Select placeholder="选择需求类型"
                        style={{ width: 120 }}
                        value={this.state.demandType}
                        onChange={(e) => { this.setState({ demandType: e }) }}>
                        {this.state.demandTypeOption}
                    </Select>
                    <Select placeholder="选择需求状态" style={{ width: 120 }}
                        value={this.state.status}
                        onChange={(e) => { this.setState({ status: e }) }}>
                        <Select.Option value="0" >进行中</Select.Option>
                        <Select.Option value="1" >未解决</Select.Option>
                        <Select.Option value="2" >已解决</Select.Option>
                    </Select>
                    <Select placeholder="选择审核状态" style={{ width: 160 }}
                        value={this.state.auditStatus}
                        onChange={(e) => { this.setState({ auditStatus: e }) }}>
                        <Select.Option value="0" >未提交审核(草稿)</Select.Option>
                        <Select.Option value="1" >提交审核</Select.Option>
                        <Select.Option value="2" >审核中</Select.Option>
                        <Select.Option value="3" >审核通过</Select.Option>
                        <Select.Option value="4" >审核未通过</Select.Option>
                    </Select>
                    <Button type="primary" onClick={this.search}>搜索</Button>
                    <Button onClick={this.reset}>重置</Button>
                    <Button style={{ background: "#3fcf9e", border: "none", color: "#fff" }}
                        disabled={!hasSelected}
                        onClick={this.delectRow}>删除<Icon type="minus" /></Button>
                    <span>更多搜索<Switch defaultChecked={false} onChange={this.searchSwitch} /></span>
                    <div className="search-more" style={this.state.searchMore ? { display: 'none' } : {}}>
                        <Select placeholder="选择是否发布" style={{ width: 120 }}
                            value={this.state.releaseStatus}
                            onChange={(e) => { this.setState({ releaseStatus: e }) }}>
                            <Select.Option value="0" >未发布</Select.Option>
                            <Select.Option value="1" >已发布</Select.Option>
                        </Select>
                        <span>有效期限 :</span>
                        <RangePicker
                            value={[this.state.validityPeriodDate[0] ? moment(this.state.validityPeriodDate[0]) : null,
                            this.state.validityPeriodDate[1] ? moment(this.state.validityPeriodDate[1]) : null]}
                            onChange={(data, dataString) => { this.setState({ validityPeriodDate: dataString }); }} />
                        <span>发布时间 :</span>
                        <RangePicker
                            value={[this.state.releaseDate[0] ? moment(this.state.releaseDate[0]) : null,
                            this.state.releaseDate[1] ? moment(this.state.releaseDate[1]) : null]}
                            onChange={(data, dataString) => { this.setState({ releaseDate: dataString }); }} />
                    </div>
                </div>
                <div className="patent-table">
                    <Spin spinning={this.state.loading}>
                        <Table columns={this.state.columns}
                            dataSource={this.state.dataSource}
                            rowSelection={rowSelection}
                            pagination={this.state.pagination}
                            onRowClick={this.tableRowClick} />
                    </Spin>
                </div>
                <TechDemandDesc
                    data={this.state.RowData}
                    demandTypeOption={this.state.demandTypeOption}
                    showDesc={this.state.showDesc}
                    closeDesc={this.closeDesc} />
            </div >
        );
    }
});

export default DemandList;